FeaturizedMessagePassingRepresentation
======================================

.. currentmodule:: pykeen.nn.pyg

.. autoclass:: FeaturizedMessagePassingRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~FeaturizedMessagePassingRepresentation.pass_messages

   .. rubric:: Methods Documentation

   .. automethod:: pass_messages
